@@ -7,7 +7,9 @@ from distutils.dir_util import copy_tree
 
 from funcy import retry
 
-from dvc.utils import remove
+from dvc.config import NoRemoteError
+from dvc.exceptions import RemoteNotSpecifiedInExternalRepoError
+from dvc.utils.fs import remove
 
 
 REPO_CACHE = {}
@@ -19,7 +21,10 @@ def external_repo(url=None, rev=None, rev_lock=None, cache_dir=None):
 
     path = _external_repo(url=url, rev=rev_lock or rev, cache_dir=cache_dir)
     repo = Repo(path)
-    yield repo
+    try:
+        yield repo
+    except NoRemoteError as exc:
+        raise RemoteNotSpecifiedInExternalRepoError(url, cause=exc)
     repo.close()
 
 
