@@ -1,15 +1,12 @@
 """Helpers for other modules."""
 from __future__ import unicode_literals
 
-import errno
 import hashlib
 import json
 import logging
 import math
 import os
 import re
-import shutil
-import stat
 import sys
 import time
 
@@ -159,33 +156,6 @@ def makedirs(path, exist_ok=False, mode=None):
         os.umask(umask)
 
 
-def _chmod(func, p, excinfo):
-    perm = os.lstat(p).st_mode
-    perm |= stat.S_IWRITE
-
-    try:
-        os.chmod(p, perm)
-    except OSError as exc:
-        # broken symlink or file is not owned by us
-        if exc.errno not in [errno.ENOENT, errno.EPERM]:
-            raise
-
-    func(p)
-
-
-def remove(path):
-    logger.debug("Removing '{}'".format(relpath(path)))
-
-    try:
-        if os.path.isdir(path):
-            shutil.rmtree(path, onerror=_chmod)
-        else:
-            _chmod(os.unlink, path, None)
-    except OSError as exc:
-        if exc.errno != errno.ENOENT:
-            raise
-
-
 def _split(list_to_split, chunk_size):
     return [
         list_to_split[i : i + chunk_size]
@@ -292,16 +262,6 @@ def fix_env(env=None):
     return env
 
 
-def convert_to_unicode(data):
-    if isinstance(data, builtin_str):
-        return str(data)
-    if isinstance(data, dict):
-        return dict(map(convert_to_unicode, data.items()))
-    if isinstance(data, (list, tuple)):
-        return type(data)(map(convert_to_unicode, data))
-    return data
-
-
 def tmp_fname(fname):
     """ Temporary name for a partial download """
     return fspath(fname) + "." + str(uuid()) + ".tmp"
