@@ -143,6 +143,15 @@ if is_py2:
         def __exit__(self, *args):
             self.close()
 
+    def convert_to_unicode(data):
+        if isinstance(data, builtin_str):
+            return str(data)
+        if isinstance(data, dict):
+            return dict(map(convert_to_unicode, data.items()))
+        if isinstance(data, (list, tuple)):
+            return type(data)(map(convert_to_unicode, data))
+        return data
+
 
 elif is_py3:
     import pathlib  # noqa: F401
@@ -170,6 +179,9 @@ elif is_py3:
     range = range  # noqa: F821
     FileNotFoundError = FileNotFoundError
 
+    def convert_to_unicode(data):
+        return data
+
 
 # Backport os.fspath() from Python 3.6
 try:
